==> haskell-logging-facade-0.3.0-53-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logging-facade
version: 0.3.0
id: logging-facade-0.3.0-IuRLB4hoJARJpjkO2wQ67r
key: logging-facade-0.3.0-IuRLB4hoJARJpjkO2wQ67r
license: MIT
copyright: (c) 2014-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/logging-facade#readme
synopsis: Simple logging abstraction that allows multiple back-ends
description:
    Simple logging abstraction that allows multiple back-ends
category: System
abi: 9464c34fb0f3454c9f665c0ab40a6a83
exposed: True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types
hidden-modules: Paths_logging_facade
import-dirs: /usr/lib/ghc-8.6.5/site-local/logging-facade-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/logging-facade-0.3.0
hs-libraries: HSlogging-facade-0.3.0-IuRLB4hoJARJpjkO2wQ67r
depends:
    base-4.12.0.0 call-stack-0.2.0-7kE9ck8b3cWExm7jAiSNAI
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock
haddock-html: /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logging-facade-0.3.0-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logging-facade
version: 0.3.0
id: logging-facade-0.3.0-Bj7fy5kRxyLADSu1BKMdzi
key: logging-facade-0.3.0-Bj7fy5kRxyLADSu1BKMdzi
license: MIT
copyright: (c) 2014-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/logging-facade#readme
synopsis: Simple logging abstraction that allows multiple back-ends
description:
    Simple logging abstraction that allows multiple back-ends
category: System
abi: 87c7ada0d7d5372f89594dba9bff4963
exposed: True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types
hidden-modules: Paths_logging_facade
import-dirs: /usr/lib/ghc-8.6.5/site-local/logging-facade-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/logging-facade-0.3.0
hs-libraries: HSlogging-facade-0.3.0-Bj7fy5kRxyLADSu1BKMdzi
depends:
    base-4.12.0.0 call-stack-0.2.0-7WtbHJpXoU7ImWgyG0WuEu
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock
haddock-html: /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
